aboutsummaryrefslogtreecommitdiffstats
path: root/epan/proto.h
diff options
context:
space:
mode:
authorJakub Zawadzki <darkjames-ws@darkjames.pl>2013-12-07 10:41:42 +0000
committerJakub Zawadzki <darkjames-ws@darkjames.pl>2013-12-07 10:41:42 +0000
commitc67d38cf15be33536de6da517221cf7ce7285f8e (patch)
tree04c4ab87fa58c5c3258c2936a93a43a5b0c366a5 /epan/proto.h
parent113b078a4d80a2aee7dbecb7724aebbec5de2dfc (diff)
Rename base_display_* to field_display
This is preparation to support ->display for FT_STRING values. svn path=/trunk/; revision=53820
Diffstat (limited to 'epan/proto.h')
-rw-r--r--epan/proto.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/epan/proto.h b/epan/proto.h
index d3badde030..ef7c23b8f7 100644
--- a/epan/proto.h
+++ b/epan/proto.h
@@ -314,12 +314,12 @@ WS_DLL_PUBLIC WS_MSVC_NORETURN void proto_report_dissector_bug(const char *messa
/* Values for header_field_info.display */
/* For integral types, the display format is a base_display_e value
* possibly ORed with BASE_RANGE_STRING. */
/** BASE_DISPLAY_E_MASK selects the base_display_e value. Its current
* value means that we may have at most 16 base_display_e values. */
#define BASE_DISPLAY_E_MASK 0x0F
typedef enum {
BASE_NONE, /**< none */
@@ -329,9 +329,9 @@ typedef enum {
BASE_DEC_HEX, /**< decimal (hexadecimal) */
BASE_HEX_DEC, /**< hexadecimal (decimal) */
BASE_CUSTOM /**< call custom routine (in ->strings) to format */
-} base_display_e;
+} field_display_e;
-/* Following constants have to be ORed with a base_display_e when dissector
+/* Following constants have to be ORed with a field_display_e when dissector
* want to use specials value-string MACROs for a header_field_info */
#define BASE_RANGE_STRING 0x10
#define BASE_EXT_STRING 0x20
@@ -314,12 +314,12 @@ WS_DLL_PUBLIC WS_MSVC_NORETURN void proto_report_dissector_bug(const char *messa
/* Values for header_field_info.display */
-/* For integral types, the display format is a base_display_e value
- * possibly ORed with BASE_RANGE_STRING. */
+/* For integral types, the display format is a BASE_* field_display_e value
+ * possibly ORed with BASE_*_STRING */
-/** BASE_DISPLAY_E_MASK selects the base_display_e value. Its current
- * value means that we may have at most 16 base_display_e values. */
-#define BASE_DISPLAY_E_MASK 0x0F
+/** FIELD_DISPLAY_E_MASK selects the field_display_e value. Its current
+ * value means that we may have at most 16 field_display_e values. */
+#define FIELD_DISPLAY_E_MASK 0x0F
typedef enum {
BASE_NONE, /**< none */